@@ -4,8 +4,9 @@
 #include "authenticationwindow.h"
 #include "plugin.h"
 
-GetOpinionSink::GetOpinionSink(const PluginInterface *interface) : SinkPlugin(interface) {
-
+GetOpinionSink::GetOpinionSink(const PluginInterface *interface) : PluginAction(interface) {
+    image = QImage(":/images/logo.png");
+    image = image.scaledToHeight(48, Qt::SmoothTransformation);
 }
 
 void GetOpinionSink::clickAction(QWidget *parentWindow) {
@@ -20,3 +21,7 @@ void GetOpinionSink::clickAction(QWidget *parentWindow) {
 void GetOpinionSink::setPlugin(Plugin *plugin) {
     this->plugin = plugin;
 }
+
+QImage GetOpinionSink::getImage() {
+    return image;
+}
